==> kotlin-compiler-0.9.66-sources.jar: org/jetbrains/jet/lang/resolve/kotlin/VirtualFileKotlinClass.kt <==
/*
 * Copyright 2010-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.lang.resolve.kotlin

import com.intellij.ide.highlighter.JavaClassFileType
import com.intellij.openapi.diagnostic.Logger
import com.intellij.openapi.vfs.VirtualFile
import org.jetbrains.jet.lang.resolve.name.ClassId
import org.jetbrains.jet.lang.resolve.kotlin.header.KotlinClassHeader
import org.jetbrains.jet.utils.*

import java.io.IOException

public class VirtualFileKotlinClass private(
        public val file: VirtualFile,
        className: ClassId,
        classHeader: KotlinClassHeader,
        innerClasses: FileBasedKotlinClass.InnerClassesInfo
) : FileBasedKotlinClass(className, classHeader, innerClasses) {

    override fun getFileContents(): ByteArray {
        try {
            return file.contentsToByteArray()
        }
        catch (e: IOException) {
            LOG.error(renderFileReadingErrorMessage(file), e)
            throw rethrow(e)
        }
    }

    override fun equals(other: Any?) = other is VirtualFileKotlinClass && other.file == file
    override fun hashCode() = file.hashCode()
    override fun toString() = "${javaClass.getSimpleName()}: $file"

    class object {
        private val LOG = Logger.getInstance(javaClass<VirtualFileKotlinClass>())

        deprecated("Use KotlinBinaryClassCache")
        fun create(file: VirtualFile): VirtualFileKotlinClass? {
            assert(file.getFileType() == JavaClassFileType.INSTANCE) { "Trying to read binary data from a non-class file $file" }
            try {
                return FileBasedKotlinClass.create(file.contentsToByteArray()) {
                    name, header, innerClasses ->
                    VirtualFileKotlinClass(file, name, header, innerClasses)
                }
            }
            catch (e: Throwable) {
                LOG.warn(renderFileReadingErrorMessage(file))
                return null
            }
        }

        private fun renderFileReadingErrorMessage(file: VirtualFile): String =
                "Could not read file: ${file.getPath()}; size in bytes: ${file.getLength()}; file type: ${file.getFileType().getName()}"
    }
}

==> kotlin-compiler-0.9.976-sources.jar: org/jetbrains/jet/lang/resolve/kotlin/VirtualFileKotlinClass.kt <==
/*
 * Copyright 2010-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.lang.resolve.kotlin

import com.intellij.ide.highlighter.JavaClassFileType
import com.intellij.openapi.diagnostic.Logger
import com.intellij.openapi.vfs.VirtualFile
import org.jetbrains.jet.lang.resolve.name.ClassId
import org.jetbrains.jet.lang.resolve.kotlin.header.KotlinClassHeader
import org.jetbrains.jet.utils.*

import java.io.IOException

public class VirtualFileKotlinClass private(
        public val file: VirtualFile,
        className: ClassId,
        classHeader: KotlinClassHeader,
        innerClasses: FileBasedKotlinClass.InnerClassesInfo
) : FileBasedKotlinClass(className, classHeader, innerClasses) {

    override fun getFileContents(): ByteArray {
        try {
            return file.contentsToByteArray()
        }
        catch (e: IOException) {
            LOG.error(renderFileReadingErrorMessage(file), e)
            throw rethrow(e)
        }
    }

    override fun equals(other: Any?) = other is VirtualFileKotlinClass && other.file == file
    override fun hashCode() = file.hashCode()
    override fun toString() = "${javaClass.getSimpleName()}: $file"

    class object {
        private val LOG = Logger.getInstance(javaClass<VirtualFileKotlinClass>())

        deprecated("Use KotlinBinaryClassCache")
        fun create(file: VirtualFile): VirtualFileKotlinClass? {
            assert(file.getFileType() == JavaClassFileType.INSTANCE) { "Trying to read binary data from a non-class file $file" }
            val byteContent = file.contentsToByteArray()
            if (byteContent.isEmpty()) return null

            try {
                return FileBasedKotlinClass.create(byteContent) {
                    name, header, innerClasses ->
                    VirtualFileKotlinClass(file, name, header, innerClasses)
                }
            }
            catch (e: Throwable) {
                LOG.warn(renderFileReadingErrorMessage(file))
                return null
            }
        }

        private fun renderFileReadingErrorMessage(file: VirtualFile): String =
                "Could not read file: ${file.getPath()}; size in bytes: ${file.getLength()}; file type: ${file.getFileType().getName()}"
    }
}
